package money.ui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.WindowConstants;

import money.model.Bilancio;

public class MainFrame extends JFrame implements ActionListener
{

	private static final long serialVersionUID = 1L;
	private SummaryPanel bilancioSummaryPanel;
	private SummaryPanel contoSummaryPanel;
	private JButton movimentiButton;
	private JButton saveButton;
	private Controller controller;
	private JComboBox contoComboBox;

	public MainFrame()
	{
		initGUI();
		pack();
	}

	protected void initGUI()
	{
		setTitle("Bilancio");
		getContentPane().setBackground(Color.WHITE);
		setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
		
		JPanel buttonsPanel = new JPanel();
		{
			movimentiButton = new JButton();
			buttonsPanel.add(movimentiButton);
			movimentiButton.setText("Visualizza movimenti");
			movimentiButton.addActionListener(this);

			saveButton = new JButton();
			buttonsPanel.add(saveButton);
			saveButton.setText("Salva");
			saveButton.addActionListener(this);
		}
		getContentPane().add(buttonsPanel, BorderLayout.PAGE_START);
		
		JPanel summariesPanel = new JPanel();
		summariesPanel.setLayout(new GridLayout(2, 1, 5, 5));
		{
			bilancioSummaryPanel = new SummaryPanel();
			summariesPanel.add(bilancioSummaryPanel);
			
			JPanel contiPanel = new JPanel();
			{
				contiPanel.setBackground(Color.WHITE);
				contiPanel.setLayout(new BorderLayout());

				contoComboBox = new JComboBox();
				contoComboBox.addActionListener(this);
				contiPanel.add(contoComboBox, BorderLayout.PAGE_START);

				contoSummaryPanel = new SummaryPanel();
				contiPanel.add(contoSummaryPanel, BorderLayout.CENTER);
			}
			summariesPanel.add(contiPanel);
		}
		getContentPane().add(summariesPanel, BorderLayout.CENTER);

		pack();
//		setExtendedState(MAXIMIZED_BOTH);
	}

	private void refreshData()
	{
		bilancioSummaryPanel.refreshData();
		contoSummaryPanel.refreshData();
	}

	@Override
	public void actionPerformed(ActionEvent e)
	{
		Object source = e.getSource();
		if (source == movimentiButton)
			onMovimentiClick();
		else if (source == saveButton)
			onSaveClick();
		else if (source == contoComboBox)
			onContoComboBoxChanged();
	}

	private void onContoComboBoxChanged()
	{
		String nome = contoComboBox.getSelectedItem().toString();
		Bilancio conto = controller.getConto(nome);
		contoSummaryPanel.setBilancio(conto);
	}

	private void onMovimentiClick()
	{
		controller.openMovimenti();
		refreshData();
	}

	private void onSaveClick()
	{
		controller.save();
	}

	public void setController(Controller controller)
	{
		this.controller = controller;
		for (String nomeConto : this.controller.getConti())
		{
			contoComboBox.addItem(nomeConto);
		}
		if (contoComboBox.getItemCount() > 0)
		{
			contoComboBox.setSelectedIndex(0);
		}
		bilancioSummaryPanel.setBilancio(this.controller.getBilancioFamiliare());
	}

}
